# Cassini

A virtual lab-book, using Jupyter Lab and Python. 

![Screenshot](doc_src/_static/JLGui.png)

### Installation

Head to [Quickstart](https://0hughman0.github.io/Cassini/latest/quickstart.html) to get going.

